@@ -1,9 +1,10 @@
-from typing import List, Union, Optional
 import os
-from pathlib import Path
 import re
 import shutil
+import sys
 import urllib.request
+from pathlib import Path
+from typing import List, Optional, Union
 
 from ._version import SHINYLIVE_ASSETS_VERSION
 
@@ -27,10 +28,10 @@ def download_shinylive(
     tmp_name = None
 
     try:
-        print(f"Downloading {url}...")
+        print(f"Downloading {url}...", file=sys.stderr)
         tmp_name, _ = urllib.request.urlretrieve(url)
 
-        print(f"Unzipping to {destdir}/")
+        print(f"Unzipping to {destdir}/", file=sys.stderr)
         with tarfile.open(tmp_name) as tar:
             tar.extractall(destdir)
     finally:
@@ -84,12 +85,36 @@ def copy_shinylive_local(
 
     target_dir = destdir / f"shinylive-{version}"
 
+    source_dir = Path(source_dir)
+
     if target_dir.exists():
         shutil.rmtree(target_dir)
 
     shutil.copytree(source_dir, target_dir)
 
 
+def link_shinylive_local(
+    source_dir: Union[str, Path],
+    destdir: Optional[Union[str, Path]] = None,
+    version: str = SHINYLIVE_ASSETS_VERSION,
+):
+    if destdir is None:
+        destdir = Path(shinylive_cache_dir())
+
+    destdir = Path(destdir)
+
+    target_dir = destdir / f"shinylive-{version}"
+
+    source_dir = Path(source_dir).absolute()
+    if not source_dir.is_dir():
+        raise RuntimeError("Source directory does not exist: " + str(source_dir))
+
+    if target_dir.exists():
+        shutil.rmtree(target_dir)
+
+    target_dir.symlink_to(source_dir)
+
+
 def ensure_shinylive_assets(
     destdir: Union[Path, None] = None,
     version: str = SHINYLIVE_ASSETS_VERSION,
@@ -104,12 +129,12 @@ def ensure_shinylive_assets(
         url = shinylive_bundle_url(version)
 
     if not destdir.exists():
-        print("Creating directory " + str(destdir))
+        print("Creating directory " + str(destdir), file=sys.stderr)
         destdir.mkdir(parents=True)
 
     shinylive_bundle_dir = Path(shinylive_assets_dir(version))
     if not shinylive_bundle_dir.exists():
-        print(f"{shinylive_bundle_dir} does not exist.")
+        print(f"{shinylive_bundle_dir} does not exist.", file=sys.stderr)
         download_shinylive(url=url, version=version, destdir=destdir)
 
     return shinylive_bundle_dir
@@ -171,7 +196,9 @@ def remove_shinylive_assets(
 
     for target_dir in target_dirs:
         print("Removing " + str(target_dir))
-        if target_dir.exists():
+        if target_dir.is_symlink():
+            target_dir.unlink()
+        elif target_dir.is_dir():
             shutil.rmtree(target_dir)
         else:
             print(f"{target_dir} does not exist.")
